@@ -1,4 +1,4 @@
 
 trace <- function(mat){
-  return(sum(diag(mat)))
+  sum(diag(mat))
 }
